{% extends base %}
{% load date_extras %}

{% block script %}
    $(function () {
        $('#search_date').datetimepicker({
            locale: 'fr',
            format: 'DD/MM/YYYY'
        });
    });
    $(function() {
        $('#service_id').bootstrapToggle();
    })
{% endblock %}

{% block content %}

{% include "components/banners.html" %}

<form method="post" id="form">
    {% csrf_token %}
    <input type="hidden" id="action" name="action"/>
    <input type="hidden" id="sort" name="sort" value="{{sort}}"/>
    <input type="hidden" name="path" value=":/django/logs"/>
    {% include "components/table.html" with table=table pagination=pagination %}
</form>

{% endblock %}