{% extends base %}
{% block title %}
<title>{{ title }}</title>
{% endblock %}
{% block content %}
<form action="" id="form" method="post">
    {% csrf_token %}
    <input type="hidden" id="action"/>
    <input type="hidden" name="archive"/>
    <input type="hidden" name="bank" value="{{bank}}"/>
    <input type="hidden" name="back" value="{{back}}"/>
    <div class="panel panel-default">
        <div class="panel-heading">Confirmer l'archivage</div>
        <div class="panel-body">
        <p>{{ message }}</p>
        </div>
        <div class="panel-footer">
            <button type="button" class="btn btn-default" onclick="open2('{{ cancel }}')">Annuler</button>
            {% if not error %}
            <button type="submit" class="btn btn-danger">Archiver</button>
            {% endif %}
        </div>
    </div>
</form>
{% endblock %}