{% extends base %}
{% load form_extras %}

{% block content %}

    <form id="form" method="post">
        {% csrf_token %}
        <input type="hidden" id="action" name="action" value="print"/>
        <input type="hidden" id="report" name="report" value="{{ report }}"/>
        <input type="hidden" id="search" name="search" value="{{ search }}"/>
        <input type="hidden" id="filter_key" name="filter_key" value="{{ filter_key }}"/>
        <input type="hidden" name="back" value="{{ back }}"/>

        {% if error %}
        <div class="alert alert-danger">
            {{ error_message }}
        </div>
        {% endif %}

        <div class="panel panel-default">
            <div class="panel-body">
                {% include "components/field_text_short.html" with field=form|field:'title' %}
            </div>
            <div class="panel-footer">
                <button type="button" class="btn btn-default" onclick="go_back('{{ back }}')">Annuler</button>
                <button type="submit" class="btn btn-primary">Imprimer</button>
            </div>
        </div>

    </form>

{% endblock %}